/*
 * Copyright 2010-2012 Ning, Inc.
 *
 * Ning licenses this file to you under the Apache License, version 2.0
 * (the "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at:
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */

package com.ning.billing.util.entity.dao;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.UUID;
import java.util.concurrent.atomic.AtomicLong;

import com.ning.billing.BillingExceptionBase;
import com.ning.billing.util.callcontext.InternalCallContext;
import com.ning.billing.util.callcontext.InternalTenantContext;
import com.ning.billing.util.entity.Entity;

import com.google.common.collect.ImmutableMap;

public class MockEntityDaoBase<M extends EntityModelDao<E>, E extends Entity, U extends BillingExceptionBase> implements EntityDao<M, E, U> {

    protected static final AtomicLong autoIncrement = new AtomicLong(1);

    protected final Map<UUID, Map<Long, M>> entities = new HashMap<UUID, Map<Long, M>>();

    @Override
    public void create(final M entity, final InternalCallContext context) throws U {
        entities.put(entity.getId(), ImmutableMap.<Long, M>of(autoIncrement.incrementAndGet(), entity));
    }

    @Override
    public Long getRecordId(final UUID id, final InternalTenantContext context) {
        return entities.get(id).keySet().iterator().next();
    }

    @Override
    public M getByRecordId(final Long recordId, final InternalTenantContext context) {
        for (final Map<Long, M> cur : entities.values()) {
            if (cur.keySet().iterator().next().equals(recordId)) {
                cur.values().iterator().next();
            }
        }
        return null;
    }

    @Override
    public M getById(final UUID id, final InternalTenantContext context) {
        return entities.get(id).values().iterator().next();
    }

    @Override
    public List<M> get(final InternalTenantContext context) {
        final List<M> result = new ArrayList<M>();
        for (final Map<Long, M> cur : entities.values()) {
            result.add(cur.values().iterator().next());
        }
        return result;
    }

    public void update(final M entity, final InternalCallContext context) {
        final Long entityRecordId = getRecordId(entity.getId(), context);
        entities.get(entity.getId()).put(entityRecordId, entity);
    }

    public void delete(final M entity, final InternalCallContext context) {
        entities.remove(entity.getId());
    }

    @Override
    public void test(final InternalTenantContext context) {
    }
}
